@@ -29,7 +29,14 @@ import chess.engine
 import chess.svg
 
 from typing import Any, Callable, Dict, Generic, Iterable, Iterator, List, Mapping, MutableMapping, Set, TextIO, Tuple, Type, TypeVar, Optional, Union
-from chess import Square
+from chess import Color, Square
+
+try:
+    from typing import Literal
+    _TrueLiteral = Literal[True]
+except ImportError:
+    # Before Python 3.8.
+    _TrueLiteral = bool  # type: ignore
 
 
 LOGGER = logging.getLogger(__name__)
@@ -154,12 +161,47 @@ class _AcceptFrame:
 
 
 class GameNode:
-    def __init__(self) -> None:
-        self.parent: Optional[GameNode] = None
-        self.variations: List[GameNode] = []
 
-        self.move: Optional[chess.Move] = None
-        self.nags: Set[int] = set()
+    parent: Optional[GameNode]
+    """
+    The parent node or ``None`` if this is the root node of the game.
+    """
+
+    move: Optional[chess.Move]
+    """
+    The move leading to this node or ``None`` if this is the root node of the
+    game.
+    """
+
+    nags: Set[int]
+    """
+    A set of NAGs as integers. NAGs always go behind a move, so the root
+    node of the game will never have NAGs.
+    """
+
+    comment: str
+    """
+    A comment that goes behind the move leading to this node. Comments
+    that occur before any moves are assigned to the root node.
+    """
+
+    starting_comment: str
+    """
+    A comment for the start of a variation. Only nodes that
+    actually start a variation (:func:`~chess.pgn.GameNode.starts_variation()`
+    checks this) can have a starting comment. The root node can not have
+    a starting comment.
+    """
+
+    variations: List[GameNode]
+    """A list of child nodes."""
+
+    def __init__(self) -> None:
+        self.parent = None
+        self.variations = []
+
+        self.move = None
+        self.nags = set()
         self.starting_comment = ""
         self.comment = ""
 
@@ -212,6 +254,31 @@ class GameNode:
         assert self.move is not None, "cannot get move of dangling GameNode"
         return self.move
 
+    def _ply(self) -> int:
+        assert False, "cannot get ply of dangling GameNode"
+
+    def ply(self) -> int:
+        """
+        Returns the number of half-moves up to this node, as indicated by
+        fullmove number and turn of the position.
+        See :func:`chess.Board.ply()`.
+
+        Usually this is equal to the number of parent nodes, but it may be
+        more if the game was started from a custom position.
+        """
+        ply = 0
+        node = self
+        while node.parent is not None:
+            ply += 1
+            node = node.parent
+        return node._ply() + ply
+
+    def turn(self) -> Color:
+        """
+        Gets the color to move at this node. See :data:`chess.Board.turn`.
+        """
+        return self.ply() % 2 == 0
+
     def san(self) -> str:
         """
         Gets the standard algebraic notation of the move leading to this node.
@@ -370,11 +437,11 @@ class GameNode:
         return node
 
     def mainline(self) -> Mainline[GameNode]:
-        """Returns an iterator over the mainline starting after this node."""
+        """Returns an iterable over the mainline starting after this node."""
         return Mainline(self, lambda node: node)
 
     def mainline_moves(self) -> Mainline[chess.Move]:
-        """Returns an iterator over the main moves after this node."""
+        """Returns an iterable over the main moves after this node."""
         return Mainline(self, lambda node: node._move())
 
     def add_line(self, moves: Iterable[chess.Move], *, comment: str = "", starting_comment: str = "", nags: Iterable[int] = []) -> GameNode:
@@ -407,11 +474,21 @@ class GameNode:
         match = EVAL_REGEX.search(self.comment)
         if not match:
             return None
+
+        turn = self.turn()
+
         if match.group(1):
             mate = int(match.group(1))
-            return chess.engine.PovScore(chess.engine.Mate(mate), chess.WHITE) if mate else None
+            score: chess.engine.Score = chess.engine.Mate(mate)
+            if mate == 0:
+                # Resolve this ambiguity in the specification in favor of
+                # standard chess: The player to move after mate is the player
+                # who has been mated.
+                return chess.engine.PovScore(score, turn)
         else:
-            return chess.engine.PovScore(chess.engine.Cp(int(float(match.group(2)) * 100)), chess.WHITE)
+            score = chess.engine.Cp(int(float(match.group(2)) * 100))
+
+        return chess.engine.PovScore(score if turn else -score, turn)
 
     def set_eval(self, score: Optional[chess.engine.PovScore]) -> None:
         """
@@ -628,14 +705,36 @@ class Game(GameNode):
     :class:`~chess.pgn.GameNode`.
     """
 
+    headers: Headers
+    """
+    A mapping of headers. By default, the following 7 headers are provided
+    (Seven Tag Roster):
+
+    >>> import chess.pgn
+    >>>
+    >>> game = chess.pgn.Game()
+    >>> game.headers
+    Headers(Event='?', Site='?', Date='????.??.??', Round='?', White='?', Black='?', Result='*')
+    """
+
+    errors: List[Exception]
+    """
+    A list of errors (such as illegal or ambiguous moves) encountered while
+    parsing the game.
+    """
+
     def __init__(self, headers: Optional[Union[Mapping[str, str], Iterable[Tuple[str, str]]]] = None) -> None:
         super().__init__()
         self.headers = Headers(headers)
-        self.errors: List[Exception] = []
+        self.errors = []
 
     def _board(self) -> chess.Board:
         return self.headers.board()
 
+    def _ply(self) -> int:
+        # Optimization: Parse FEN only for custom starting positions.
+        return self.board().ply() if "FEN" in self.headers else 0
+
     def setup(self, board: Union[chess.Board, str]) -> None:
         """
         Sets up a specific starting position. This sets (or resets) the
@@ -1127,7 +1226,7 @@ class BoardBuilder(BaseVisitor[chess.Board]):
         return self.board
 
 
-class SkipVisitor(BaseVisitor["typing.Literal[True]"]):
+class SkipVisitor(BaseVisitor[_TrueLiteral]):
     """Skips a game."""
 
     def begin_game(self) -> SkipType:
@@ -1139,7 +1238,7 @@ class SkipVisitor(BaseVisitor["typing.Literal[True]"]):
     def begin_variation(self) -> SkipType:
         return SKIP
 
-    def result(self) -> "typing.Literal[True]":
+    def result(self) -> _TrueLiteral:
         return True
 
 
